# Changelog

## 1.3.0 (2021.09.27)

- Add support for Wagtail 2.13+ (@marts)
- Breaking change: Drop support for Wagtail 2.12 and older

## 1.2.0 (2020.01.10)

- Add additional text field for handling color values manually (@marts)
